@@ -15,9 +15,12 @@ from sphinx_autobuild.utils import show_command, show_message
 
 
 class Builder:
-    def __init__(self, sphinx_args, *, url_host, pre_build_commands):
+    def __init__(
+        self, sphinx_args, *, url_host, pre_build_commands, post_build_commands
+    ):
         self.sphinx_args = sphinx_args
         self.pre_build_commands = pre_build_commands
+        self.post_build_commands = post_build_commands
         self.uri = f"http://{url_host}"
 
     def __call__(self, *, changed_paths: Sequence[Path]):
@@ -35,24 +38,7 @@ class Builder:
                 show_message(f"Detected changes ({', '.join(rel_paths)})")
             show_message("Rebuilding...")
 
-        try:
-            for command in self.pre_build_commands:
-                show_message("pre-build")
-                show_command(command)
-                subprocess.run(command, check=True)
-        except subprocess.CalledProcessError as e:
-            print(f"Pre-build command exited with exit code: {e.returncode}")
-            print(
-                "Please fix the cause of the error above or press Ctrl+C to stop the "
-                "server."
-            )
-            print(
-                "The server will continue serving the build folder, but the contents "
-                "being served are no longer in sync with the documentation sources. "
-                "Please fix the cause of the error above or press Ctrl+C to stop the "
-                "server."
-            )
-            traceback.print_exception(e)
+        if self._run_commands(self.pre_build_commands, "pre-build") != 0:
             return
 
         if sphinx.version_info[:3] >= (7, 2, 3):
@@ -70,5 +56,33 @@ class Builder:
                 "Please fix the cause of the error above or press Ctrl+C to stop the "
                 "server."
             )
+        else:
+            # Run the post-build commands only if the build was successful
+            self._run_commands(self.post_build_commands, "post-build")
+
         # Remind the user of the server URL for convenience.
         show_message(f"Serving on {self.uri}")
+
+    def _run_commands(self, commands, log_context):
+        try:
+            for command in commands:
+                show_message(log_context)
+                show_command(command)
+                subprocess.run(command, check=True)
+        except subprocess.CalledProcessError as e:
+            print(
+                f"{log_context.title()} command exited with exit code: {e.returncode}"
+            )
+            print(
+                "Please fix the cause of the error above or press Ctrl+C to stop the "
+                "server."
+            )
+            print(
+                "The server will continue serving the build folder, but the contents "
+                "being served are no longer in sync with the documentation sources. "
+                "Please fix the cause of the error above or press Ctrl+C to stop the "
+                "server."
+            )
+            traceback.print_exception(e)
+            return e.returncode
+        return 0
